/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							New Data
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/

		/********************Calling Data**************/
clear		
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
use "Article Coding April 2018.dta"
set more off

		/******************Initial Bit of Cleaning*****/
	/*
	There exist some remnant test coding entries that
	should be removed. These are the six articles
	that come before 2009, all of which focus on 
	Bartels' 'Partisanship and Voting Behavior' paper. 
	*/

drop if Q32_0 < 2009
	
	/*
	Next we check for whether the remaining articles take a 
	quantative approach (and qualify) or not.
	*/
	
tab Q2
	

/*
Two manual edits need to be made to address coder confusion: 

"I had mentioned before a few of my coding responses I wanted to change. 
You actually addressed most of my concerns in a previous e-mail when I asked about coding "other survey" or "experiment" 
for papers that were arguably using natural experiments. Since we decided not to change my responses 
(for the two papers in question, I marked the variables as "other survey"),
 there was only one other correction I wanted to make:

Article:  Electoral Choice, Ideological Conflict, and Political Participation
Q3: Add "Campaign Contact" to list of variables measured
Q4: For "Campaign Contact," mark "Not Central" and "Other Survey" " 
*/

list if Q31 == "Electoral Choice, Ideological Conflict, and Political Participation"
	/*entry # 15 at this point*/
	
replace Q3_25 = 1 if Q31 == "Electoral Choice, Ideological Conflict, and Political Participation"
	/*the above changes the campaign contact entry to =1 , i.e. present*/
	
replace Q4_1_x25 = 2 if Q31 == "Electoral Choice, Ideological Conflict, and Political Participation"
	/*This marks the campaign contact item for this article as not central*/
	
replace Q4_2_x25_2 = 1 if Q31 == "Electoral Choice, Ideological Conflict, and Political Participation"
	/*And this marks "Other Survey" as present for this file/measure*/
	

rename Q32_0 year
	label var year "Year"
rename Q31 title
	label var title "Article Title"
order year title, first
	
	/*
	Two of the remaining items were coded in April and also appear to be
	test codes. These are then dropped. */
	
drop if title == "sdfsdfs"
drop if title == "abcd"
	
	
	/*how many of the remaining are quantitative?
	*/

rename Q2 quant
tab quant
	
	/*
	41 of the files take a Quantitative approach, 2 do not. 
	*/

drop if quant == 2
	
	
	
/*Descriptive plot of articles coded per year*/
catplot year, scheme(plottig) vertical blabel(bar, size(medium)) ///
	ylabel(0(2)8) title(Articles Coded Per Year)

	/*
	graph save "articles per year", replace
	graph export "articles per year.png", replace
	*/

