/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							1980-2008 Data
							Data Use Over Time
							Figure 4
*******************************************************************************
*******************************************************************************
*******************************************************************************/



/****Calling and Cleaning the Data*****/

clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /*change this to where you have the data/cleaning files*/
do "1980-2008 Initial Cleaning.do"
set more off

/**
To do this, we will first create a binary indicator
that = 1 if *any* of the coded concepts/issues
is associated with ANES data and 0 otherwise.
**/

egen method1 = anymatch(Q4_2_x*_1 /*all 48 concepts*/ ///
				Q8_2_x*_1  /*jobs*/ ///
				Q10_2_x*_1 /*blacks*/ ///
				Q12_2_x*_1 /*affirm action*/ ///
				Q14_2_x*_1 /*defense*/ ///
				Q16_2_x*_1 /*women*/ ///
				Q18_2_x*_1 /*abortion*/ ///
				Q20_2_x*_1 /*death penalty*/ ///
				Q22_2_x*_1 /*gay & lesbian*/ ///
				Q24_2_x*_1 /*environment*/ ///
				Q26_2_x*_1 /*spending*/ ///
				Q28_2_x*_1 /*internationalism*/), v(1)
	label var method1 "ANES"
	
egen method2 = anymatch(Q4_2_x*_2 /*all 48 concepts*/ ///
				Q8_2_x*_2  /*jobs*/ ///
				Q10_2_x*_2 /*blacks*/ ///
				Q12_2_x*_2 /*affirm action*/ ///
				Q14_2_x*_2 /*defense*/ ///
				Q16_2_x*_2 /*women*/ ///
				Q18_2_x*_2 /*abortion*/ ///
				Q20_2_x*_2 /*death penalty*/ ///
				Q22_2_x*_2 /*gay & lesbian*/ ///
				Q24_2_x*_2 /*environment*/ ///
				Q26_2_x*_2 /*spending*/ ///
				Q28_2_x*_2 /*internationalism*/), v(1)
	label var method2 "Other Survey"


egen method3 = anymatch(Q4_2_x*_3 /*all 48 concepts*/ ///
				Q8_2_x*_3  /*jobs*/ ///
				Q10_2_x*_3 /*blacks*/ ///
				Q12_2_x*_3 /*affirm action*/ ///
				Q14_2_x*_3 /*defense*/ ///
				Q16_2_x*_3 /*women*/ ///
				Q18_2_x*_3 /*abortion*/ ///
				Q20_2_x*_3 /*death penalty*/ ///
				Q22_2_x*_3 /*gay & lesbian*/ ///
				Q24_2_x*_3 /*environment*/ ///
				Q26_2_x*_3 /*spending*/ ///
				Q28_2_x*_3 /*internationalism*/), v(1)		
	label var method3 "Experiment" 


egen method4 = anymatch(Q4_2_x*_4 /*all 48 concepts*/ ///
				Q8_2_x*_4  /*jobs*/ ///
				Q10_2_x*_4 /*blacks*/ ///
				Q12_2_x*_4 /*affirm action*/ ///
				Q14_2_x*_4 /*defense*/ ///
				Q16_2_x*_4 /*women*/ ///
				Q18_2_x*_4 /*abortion*/ ///
				Q20_2_x*_4 /*death penalty*/ ///
				Q22_2_x*_4 /*gay & lesbian*/ ///
				Q24_2_x*_4 /*environment*/ ///
				Q26_2_x*_4 /*spending*/ ///
				Q28_2_x*_4 /*internationalism*/), v(1)		
	label var method4 "Archival"
	
tab1 method*
	/*
	ANES = 33.50% (392)
	Other Survey = 50.60 (592)
	Experiment = 9.66 (113)
	Archival = 16.07 (188)
	*/
	
	
gen method5 = 0
	replace method5 = 1 if method1 == 1 | method2 == 1
	label var method5 "Any Survey"
	tab method5
		/*78.03 (35)*/
	
	
gen method6 = 0
	replace method6 = 1 if method1 == 1 & method3 == 1
	label var method6 "ANES+Experiment"
	tab method6
	/*0.34 (4)*/
	
gen method7 = 0
	replace method7 = 1 if method5 == 1 & method3 == 1
	label var method7 "Survey+Experiment"
	tab method7
	/*2.14 (6)*/
	
gen method8 = 0
	replace method8 = 1 if method5 == 1 & method4 == 1
	label var method8 "Survey & Archival"
	
	
/*******Collapsing so we have just a datafile with the over time data*****/

collapse (mean) method* , by(year)
	

label var method1 "ANES"
label var method2 "Other Survey"
label var method3 "Experiment" 
label var method4 "Archival"
label var method5 "Any Survey"
label var method6 "ANES & Experiment"
label var method7 "Survey & Experiment"
label var method8 "Survey & Archival"

	foreach var in method1 method2 method3 method4 method5 method7 method8 {
		lowess `var' year, scheme(s1mono) title("`: var label `var''", size(medlarge)) ///
				xtitle(Year) ytitle("") note("")
		graph save "`var'", replace
		}
	
graph combine "method1" "method2" "method3" "method4" ///
	"method5" "method7" "method8", ycommon scheme(s1mono) rows(2)
	
graph save "Figure 4", replace
graph export "Figure 4.png", replace

	
	
	
	