/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							1980-2008 Data
							ANES Time Series Use
							Figure 5
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/


/****Calling and Cleaning the Data*****/

clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /*change this to match your computer*/
do "1980-2008 Initial Cleaning.do"
set more off


/********Overall Use******/

/****
the following anymatch code yields binary varialbes for
each of the three potential ANES answers. 
In other words, it produces a variable = 1 if 
*any* of the concepts was coded as using the ANES 1 [2, 3] 
times.
*****/ 


egen ts1 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(1)
label var ts1 "1 ANES Used"


egen ts2 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(2)
label var ts2 "2 ANES Used"

egen ts3 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(3)
label var ts3 "3+ ANES Used"
				
tab1 ts*


tab ts1 ts2
tab ts2 ts3
tab ts1 ts3

gen ts_use = . 
	replace ts_use = 3 if ts3 == 1 & ts2 == 1 & ts1 == 1
	replace ts_use = 3 if ts3 == 1 & ts2 == 0 & ts1 == 1
	replace ts_use = 3 if ts3 == 1 & ts2 == 1 & ts1 == 0
	replace ts_use = 3 if ts3 == 1 & ts2 == 0 & ts1 == 0
	replace ts_use = 2 if ts3 == 0 & ts2 == 1 & ts1 == 1
	replace ts_use = 2 if ts3 == 0 & ts2 == 1 & ts1 == 0
	replace ts_use = 1 if ts3 == 0 & ts2 == 0 & ts1 == 1
	
label var ts_use "Use of ANES TS"
tab ts_use
	/*
	Total = 392
	One = 128 (32.65%)
	Two = 63 (16.07%)
	Three+ = 201 (51.28%)
	*/
	
recode ts_use (1=0) (2 3 = 1), gen(ts_use1)
label var ts_use1 "Use of ANES TS"
label def ts_a 0 "1 ANES Survey" 1 "2+ ANES Surveys"
label values ts_use1  ts_a

tab ts_use1
	/*264; 67.35%*/
	
	
tabulate ts_use, gen(timeseries)	

/******Reshaping*******/
gen id = _n

reshape long timeseries, i(id) j(time)

collapse (mean) timeseries,  by(time)

/*Adding the 2+ entry*/
set obs  4
replace time = 4 in 4
replace timeseries = 0.6735 in 4

label def timelabel 1 "1 ANES" 2 "2 ANES" 3 "3+ ANES" 4 "2+ ANES"
label values time timelabel
	
graph bar timeseries, over(time, ///
	relabel(1 `""1 ANES" "n=128""' 2 `""2 ANES" "n=63""' ///
			3 `""3+ ANES" "n=201""' 4 `""2+ ANES" "n=264""')  label(labsize(small))) ///
			scheme(s1mono) blabel(bar, format(%9.2g)) ///
			title("ANES Time Series Use", size(medium)) ///
			ytitle("")
			
graph save "anes 1980 to 2008 - ts use", replace
graph export "anes 1980 to 2008 - ts use", replace
	
	
/************************Now We'll create the over time graphs to combine*****/
	
	
/**Call the data*/	
	
clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /*change*/
do "1980-2008 Initial Cleaning.do"
set more off
	

egen ts1 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(1)
label var ts1 "1 ANES Used"


egen ts2 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(2)
label var ts2 "2 ANES Used"

egen ts3 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(3)
label var ts3 "3+ ANES Used"
				
tab1 ts*

tab ts1 ts2
tab ts2 ts3
tab ts1 ts3

gen ts_use = . 
	replace ts_use = 3 if ts3 == 1 & ts2 == 1 & ts1 == 1
	replace ts_use = 3 if ts3 == 1 & ts2 == 0 & ts1 == 1
	replace ts_use = 3 if ts3 == 1 & ts2 == 1 & ts1 == 0
	replace ts_use = 3 if ts3 == 1 & ts2 == 0 & ts1 == 0
	replace ts_use = 2 if ts3 == 0 & ts2 == 1 & ts1 == 1
	replace ts_use = 2 if ts3 == 0 & ts2 == 1 & ts1 == 0
	replace ts_use = 1 if ts3 == 0 & ts2 == 0 & ts1 == 1
	
label var ts_use "Use of ANES TS"
tab ts_use
	/*
	Total = 392
	One = 128 (32.65%)
	Two = 63 (16.07%)
	Three+ = 201 (51.28%)
	*/
	
recode ts_use (1=0) (2 3 = 1), gen(ts_use1)
label var ts_use1 "Use of ANES TS"
label def ts_a 0 "1 ANES Survey" 1 "2+ ANES Surveys"
label values ts_use1  ts_a

tab ts_use1
	
tabulate ts_use, gen(timeseries)	

/********collapsing the data*****/

collapse (mean) timeseries1 timeseries2 timeseries3 ts_use1, by(year)

label var timeseries1 "1 ANES Survey" 
label var timeseries2 "2 ANES Surveys"
label var timeseries3 "3+ ANES Surveys"
label var ts_use1 "2+ ANES Surveys"


foreach var in  timeseries1 timeseries2 timeseries3 ts_use1  {
		lowess `var' year, scheme(s1mono) title("`: var label `var''", size(medlarge)) ///
				xtitle(Year) ytitle("") note("")
		graph save "`var'", replace
		}
	
graph combine "anes 1980 to 2008 - ts use" "timeseries1" "timeseries2" "timeseries3" "ts_use1" ///
	, scheme(s1mono) rows(2) 
	
graph save "Figure 5", replace
graph export "Figure 5.png", replace
	
	
	
	
	
	
	
	
	
	
	







