/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							Comparing 1980-2008 with 
							2009-2018
							Figure 7
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/

/***********
We'll first create each of the subplots, and then combine them. 
Note that one must run the Figure 1/2 code first to generate
the data files that will be merged with the data file created
below to create the first two subgraphs. 
**********/

/*****************************************************
			Creating the .dta Files
			with Descriptives for Merging
			The following also features code
			to create some additional 
			descriptive plots
*****************************************************/

/******Calling & Cleaning the Data*******/
clear		
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files" /**need to update for your computer**/
do "ANES Coding Project - New Data.do" 

		
/*
To create the figures we want, we will reshape the data so that each row is
an article/concept pairing. We will then use the collapse function to 
create a new datset that that just focuses on the raw data that we want. 

To do this we will need to rename the concepts
and issues in a similar manner so that we can combine them. 
[If we wanted to treat them separately, we could skip this step.]
We will do this both for the appears/does not appear item and the
centra/not central item. 
*/

	/***Concepts****/
	
forval i = 1/48 {
	rename Q3_`i' topic`i'
	}

forval i = 1/48 {
	rename Q4_1_x`i' central`i'
	}
	
	/***Issues***/
/*
Sadly, we have to start 
at 49, so we need to do 
this the long way*/

rename Q7_1_1 topic49
rename Q7_1_2 topic50
rename Q7_1_3 topic51
rename Q7_2_1 topic52
rename Q7_2_2 topic53
rename Q7_2_3 topic54
rename Q7_3_1 topic55
rename Q7_3_2 topic56
rename Q7_3_3 topic57
rename Q7_4_1 topic58
rename Q7_4_2 topic59
rename Q7_4_3 topic60
rename Q7_5_1 topic61
rename Q7_5_2 topic62
rename Q7_5_3 topic63
rename Q7_6_1 topic64
 rename Q7_6_2 topic65
 rename Q7_6_3 topic66
 rename Q7_7_1 topic67
 rename Q7_7_2 topic68
 rename Q7_7_3 topic69
 rename Q7_8_1 topic70
 rename Q7_8_2 topic71
 rename Q7_8_3 topic72
 rename Q7_9_1 topic73
 rename Q7_9_2 topic74
 rename Q7_9_3 topic75
 rename Q7_10_1 topic76
 rename Q7_10_2 topic77
 rename Q7_10_3 topic78
 rename Q7_11_1 topic79
 rename Q7_11_2 topic80 
 rename Q7_11_3 topic81

/*jobs*/
rename Q8_1_x1 central49
rename Q8_1_x2 central50
rename Q8_1_x3 central51
/*blacks*/
rename Q21_1_x1 central52
rename Q21_1_x2 central53
rename Q21_1_x3 central54
/*affirm action*/
rename Q24_1_x1 central55
rename Q24_1_x2 central56
rename Q24_1_x3 central57
/*defense*/
rename Q26_1_x1 central58
rename Q26_1_x2 central59
rename Q26_1_x3 central60
/*women*/
rename Q28_1_x1 central61
rename Q28_1_x2 central62
rename Q28_1_x3 central63
/*abortion*/
rename Q30_1_x1 central64
 rename Q30_1_x2 central65
 rename Q30_1_x3 central66
 /*death penalty*/
 rename Q32_1_x1 central67
 rename Q32_1_x2 central68
 rename Q32_1_x3 central69
 /*gay & lesbian*/
 rename Q34_1_x1 central70
 rename Q34_1_x2 central71
 rename Q34_1_x3 central72
 /*environment*/
 rename Q36_1_x1 central73
 rename Q36_1_x2 central74
 rename Q36_1_x3 central75
 /*spending*/
 rename Q38_1_x1 central76
 rename Q38_1_x2 central77
 rename Q38_1_x3 central78
 /*internationalism*/
 rename Q40_1_x1 central79
 rename Q40_1_x2 central80 
 rename Q40_1_x3 central81


	/***Rehsaping****/

reshape long topic central, i(ResponseId) j(top)
order topic central, after(top)

recode central (2=.) 
	/*this makes the 'not central' missing data, which is 
	necessary for the 'count' code below*/

label def present 1 "Present" , replace
label def centr 1 "Central" , replace

label values topic present
label values central centr

tab1 topic central
	/*
	195 present codes; 88 central codes
	With 41 articles, this roughly = 4.8 present per article and 2.15 central
	*/
	


/***Labeling the Topic Codes****/

label def topic_code ///
 1 "Difference btw Parties" 2 "Feel About Parties" 3 "PID" ///
 4 "Party Perf.: Economy" 5 "Party Perf: Foreign Affairs" /// 
 6 "Feelings abt President" 7 "Feelings abt Pres Candidates" ///
 8 "Feelings abt Congressional Candidates" 9 "Emotions abt Pres" 10 "Emotions abt Pres Cand" ///
 11 "Likes/Dislikes abt Pres Candidates" 12 "President's Traits" 13 "Presidential Candidate's Traits" ///
 14 "Approval President Job Performance" 15 "Approval President Performance Economy" ///
 16 "Approval President Performance Foreign Policy" 17 "Approval Congress Job Performance" ///
 18 "Approval of Congressional Rep's Job Performance" ///
 19 "Economic Performance" 20 "Personal Economic Situation" 21 "Position of Country in World Affairs" ///
 22 "Political Interest" 23 "Political Knowledge" 24 "Campaign Activity" ///
 25 "Campaing Contact" 26 "Vote Choice" 27 "Turnout in Nat'l  Elections" 28 "Registration" ///
 29 "Lib/Con Values" 30 "Religious Values/Beliefs" ///
 31 "Religious Identity" 32 "Moral Traditionalism" ///
 33 "Equalitarianism" 34 "Trust in Gov't" 35 "Political Efficacy" ///
 36 "TV News Consumption" 37 "Internet News Consumption" 38 "Newspaper Consumption" ///
 39 "Radio News  Consumption" 40 "Feelings abt Social Groups" ///
 41 "Attitudes abt Blacks" 42 "Stereotypes" 43 "Racial Identity" 44 "Ethnic Identity" ///
 45 "Social Class" 46 "Personality" 47 "Problems facing Country" 48 "Att. abt Divided Gov't" ///
 49 "Jobs: Own Attitude" 50 "Jobs: Candidate" 51 "Jobs: Parties" 52 "Aid Blacks: Own Attitude" 53 "Aid Blacks: Candidate" 54 "Aid Blacks: Parties" ///
 55 "Affirmative Action:Own " 56 "Affirmative Action: Candidates" 57 "Affirmative Action: Parties" ///
 58 "Defense Spending: Own Attitude" 59 "Defense Spending: Candidates" 60 "Defense Spending: Parties" ///
 61 "Women Equality: Own Attitude" 62 "Women Equality: Candidates" 63 "Women Equality: Parties" ///
 64 "Abortion: Own Atttiude" 65  "Abortion: Candidates" 66 "Abortion: Parties" ///
 67 "Death Penalty: Own Attitude" 68 "Death Penalty: Candidates" 69 "Death Penalty: Parties" ///
 70 "Gay & Lesbian: Own Attitudes" 71 "Gay & Lesbian: Candidates" 72 "Gay & Lesbian: Parties" ///
 73 "Environment: Own Attitude" 74 "Environment: Candidates" 75 "Environment: Parties" ///
 76 "Spending: Own Attitude" 77 "Spending: Candidates" 78 "Spending: Parties" ///
 79 "Internationalism: Own Attitude" 80 "Internationalism: Candidates" 81 "Internationalism: Parties"
	
 
label values top topic_code


/*****Creating Dataset for the Item Counts******/
	
collapse (count) topic central, by(top)
list

gen id = _n
label var id "ID" 




/****Concept & Policy Use Figure********/

/***Scatterplot of rank****/
gsort -topic

gen rank_topic = _n
label var rank_topic "Rank: Topic Use"

scatter topic rank_topic, scheme(plottig) xtitle(Rank) xlabel(1(10)81) ///
	title("Distribution of Concept & Policy Use: 2009-2018", size(medium)) ///
	ytitle("# Times Coded as Present in Article (Max Possible = 43)")

graph save "most used 2009 to 2018 scatter", replace

graph export "most used 2009 to 2018 scatter.png", replace

/****Dot Plot: 10% Articles*/
graph dot topic if rank_topic >=1 & rank_topic <=17, ///
	over(rank_topic, ///
	relabel(1 "PID" 2 "Lib/Con Values" 3 "Racial Identity" 4 "Vote Choice" 5 "Turnout" ///
				6 "Attitudes abt Blacks" 7 "Ethnic Identity" 8 "Attitude: Services & Spending" ///
				9 "Feelings abt Social Groups" 10 "Religious Identity" 11 "Political Knowledge" ///
				12 "President Job Performance" 13 "Trust in Gov't" 14 "Feelings abt Parties" ///
				15 "Attitude: Enviro Protection" 16 "Attitude: Jobs & Standard of Living" ///
				17 "Feelings abt Pres. Cand.")) ///
	scheme(plotplainblind) title("Most Used Concepts: 2009-2018", size(medium)) ytitle("Frequency of Use")

graph save "17 most used 2009 to 2018 dot", replace
graph export "17 most used 2009 to 2018 dot.png", replace
	
/***Combining****/

graph combine "most used 2009 to 2018 scatter" "17 most used 2009 to 2018 dot", scheme(plottig)

/***********************Centrality*****************/

/*
The below creates proportions for the concept's centrality
both out of the times it has appeared and out of the total
number of articles and hence potential apperances. Then 
the code creates a rank order for both variables
*/


/*sort name*/

gen prop_central_appear = central/topic
	label var prop_central_appear "Prop: Central when Appearing"

	
gen prop_central_all = central/41
	label var prop_central_all "Prop: Central out of All Possible"
		

gsort -prop_central_appear
gen rank_central_appear = _n
	label var rank_central_appear "Rank: Central when Appearing"
	
gsort -prop_central_all
gen rank_central_all = _n
	label var rank_central_all "Rank: Central out of All Possible"
	
/***Central: Appear***/

gsort +rank_central_appear

list name central if rank_central_appear >=1 & rank_central_appear <=15
	
graph dot prop_central_appear if rank_central_appear >=1 & rank_central_appear <=15, ///
	over(rank_central_appear, ///
			relabel(1 "Party Performance:Foreign Affairs (1)" ///
				2 "Party Performance: Economy (1)" ///
				3 "President Performance:Foreign Affairs (1)" ///
				4 "Stereotypes (3)" 5 "President Candidate Traits (1)" ///
				6 "Diff. btwn Parties (2)" 7 "Feelings about President (2)" ///
				8 "Registration (2)" 9 "Likes/Dislikes abt Pres. Candidates (1)" ///
				10 "Congress Approval (2)" 11 "Moral Traditionalism (2)" ///
				12 "Spending & Services: Parties (1)" 13 "Feeling about Social Groups (9)" ///
				14 "Vote Choice (9)" 15 "Turnout (8)")) ///
	scheme(plotplain) title("Centrality Given Use: 2009-2018")  ytitle("Proportion 'Central' in Articles in which Concept Appears", size(vsmall))

	
graph save "centrality given use 2009 to 2018", replace
graph export "centrality given use 2009 to 2018.png", replace
	
/***Central: All***/

gsort +rank_central_all
list name central if rank_central_all >=1 & rank_central_all <=15


graph dot prop_central_all if rank_central_all >=1 & rank_central_all <=15, ///
	over(rank_central_all, ///
			relabel(1 "Vote Choice (9)" 2 "PID (8)" 3 "Turnout (8)" ///
			4 "Attitudes abt Blacks (6)" 5 "Racial Identity (5)" ///
			6 "Feelings abt Social Groups (5)" 7 "Pol. Knowledge (4)" ///
			8 "Lib/Con Values (4)" 9 "Attitude: Spending & Services (3)" ///
			10 "Stereotypes (3)" 11 "Ethnic Identity (2)" 12 "Differences btwn Parties (2)" ///
			13 "Feelings about President (2)" 14 "Trust in Gov't (2)" 15 "Moral Traditionalism (2)")) ///
	scheme(plotplain) title("Overall Centrality: 2009-2018")  ytitle("Proportion 'Central' out of All 41 Articles", size(vsmall))
	
	
graph save "overall centrality 2009 to 2018", replace
graph export "overall centrality 2009 to 2018.png", replace


/******Relationship between centrality measures*****/

/*This reverses the proportion items so that higher
= more central**/

omscore rank_central_all
	label var rr_rank_central_all "Rank: Central All (Reversed)"
omscore rank_central_appear

aaplot rank_central_appear rank_central_all , ///
	xlabel(1(10)81) ylabel(1(10)81) scheme(plottig) name(g4)

	
/******For merging with 1980-2008 data*****/

keep top topic central id

rename topic topic09
rename central central09

save "Most Used and Central - 2009 to 2018.dta" , replace
	


/*****************************************************
			Merging new and old data to create
			first two subplots
*****************************************************/


clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
use "Most Used and Central - 1980 to 2008.dta"
merge 1:1 top using "Most Used and Central - 2009 to 2018.dta"


/****labelling data****/
label var top "Concept"
label var topic "Concept Use (1980-2008)"
label var central "Centrality (1980-2008)"
label var topic09 "Concept Use (2009-2018)"
label var central09 "Centrality (2009-2018)"
order id _merge, before(top)


/****************Frequency***************/

/******scatterplot:
for this, figure we will plot the 
proportion of times used in the newer
data to the proportion used in the older
this means we need to create the proportions
********/

gen prop_topic = topic/1163
	label var prop_topic "Proportion Present (1980-2008)"
gen prop_topic09 = topic09/41
	label var prop_topic09 "Proportion Present (2009-2018)"
	
pwcorr prop_topic prop_topic09
	*r = 0.9060*

graph twoway (scatter prop_topic09 prop_topic) ///
			(lfit prop_topic09 prop_topic), scheme(s1mono)  ///
			legend(off) title("Frequency of Use") ///
			ytitle("Proportion Present (2009-2018)", size(small)) ///
			xtitle(, size(small)) text(0.50 0.05 "r = 0.91")
	

/*
In order to label the top five most used items
and do so in a legible way, we need to run the 
following to selectively label these items 
and control the label placement
*/

gen make = top if prop_topic > 0.17
label values make topic_code
	/*this was run after running other do files
		where topic_code was run; if that is not the case
		then copy and paste from a different do file
	*/
	
gen pos = 3
replace pos = 11 if make == 26
replace pos = 5 if make == 27


	
graph twoway scatter prop_topic09 prop_topic || ///
	scatter prop_topic09 prop_topic if make !=., ms(none) mlabv(pos) mla(make) legend(off) || ///
	lfit prop_topic09 prop_topic, ///
	title("Frequency of Use", size(medium)) ///
			ytitle("Proportion Present (2009-2018)", size(small)) ///
			xtitle(, size(small)) text(0.50 0.05 "r = 0.91")  scheme(s1mono)
			
	/*
	we need this set-up to avoid having a situation wherein
	the entries without a label have a . next to the scatterpoint
	*/
	
graph save "Comparison - Most Frequent", replace
graph export "Comparison - Most Frequent.png", replace
			

/***********Most Central************/
	
	
gen prop_central = central/1163
	label var prop_central "Centrality (1980-2008)"
gen prop_central09 = central09/41
	label var prop_central09 "Centrality (2009-2018)"
	
	
pwcorr prop_central prop_central09
	*r = 0.8116*

gen make2 = . 
		replace make2 = id if id == 26 | id == 3 | id == 27 | id == 29 | id == 43 ///
		| id == 40 | id == 41
label values make2 topic_code
	
	/*
	unfortunately, things will get messy in the combined graph, so 
	 i need to change the label for feelings about social groups*/
	 
	 
	label define topic_code 40 "Social Groups", modify
	

	
	
gen pos1 = 3
replace pos1 = 11 if make2 == 26 | make2 == 27	
replace pos1 = 12 if make2 == 40 | make2 == 41


scatter prop_central09 prop_central || ///
	scatter prop_central09 prop_central if make2 !=., ms(none) mlabv(pos1) mla(make2) || ///
	lfit prop_central09 prop_central, legend(off) ///
	title("Centrality", size(medium)) ///
			ytitle("Proportion Central (2009-2018)", size(small)) ///
			xtitle(, size(small)) text(0.24 0.02 "r = 0.81")  scheme(s1mono)
			

	
graph save "Comparison - Centrality", replace
graph export "Comparison - Centrality.png", replace






/*****************************************************
			Method Use in New Data
*****************************************************/
	
	

clear		
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
do "ANES Coding Project - New Data.do" 

/**
To do this, we will first create a binary indicator
that = 1 if *any* of the coded concepts/issues
is associated with ANES data and 0 otherwise.
**/


egen method1 = anymatch(Q4_2_x*_1 /*all 48 concepts*/ ///
				Q8_2_x*_1  /*jobs*/ ///
				Q21_2_x*_1 /*blacks*/ ///
				Q24_2_x*_1 /*affirm action*/ ///
				Q26_2_x*_1 /*defense*/ ///
				Q28_2_x*_1 /*women*/ ///
				Q30_2_x*_1 /*abortion*/ ///
				Q32_2_x*_1 /*death penalty*/ ///
				Q34_2_x*_1 /*gay & lesbian*/ ///
				Q36_2_x*_1 /*environment*/ ///
				Q38_2_x*_1 /*spending*/ ///
				Q40_2_x*_1 /*internationalism*/), v(1)				
	label var method1 "ANES"
	
egen method2 = anymatch(Q4_2_x*_2 /*all 48 concepts*/ ///
				Q8_2_x*_2  /*jobs*/ ///
				Q21_2_x*_2 /*blacks*/ ///
				Q24_2_x*_2 /*affirm action*/ ///
				Q26_2_x*_2 /*defense*/ ///
				Q28_2_x*_2 /*women*/ ///
				Q30_2_x*_2 /*abortion*/ ///
				Q32_2_x*_2 /*death penalty*/ ///
				Q34_2_x*_2 /*gay & lesbian*/ ///
				Q36_2_x*_2 /*environment*/ ///
				Q38_2_x*_2 /*spending*/ ///
				Q40_2_x*_2 /*internationalism*/), v(1)		
	label var method2 "Other Survey"


egen method3 = anymatch(Q4_2_x*_3 /*all 48 concepts*/ ///
				Q8_2_x*_3  /*jobs*/ ///
				Q21_2_x*_3 /*blacks*/ ///
				Q24_2_x*_3 /*affirm action*/ ///
				Q26_2_x*_3 /*defense*/ ///
				Q28_2_x*_3 /*women*/ ///
				Q30_2_x*_3 /*abortion*/ ///
				Q32_2_x*_3 /*death penalty*/ ///
				Q34_2_x*_3 /*gay & lesbian*/ ///
				Q36_2_x*_3 /*environment*/ ///
				Q38_2_x*_3 /*spending*/ ///
				Q40_2_x*_3 /*internationalism*/), v(1)		
	label var method3 "Experiment" 


egen method4 = anymatch(Q4_2_x*_4 /*all 48 concepts*/ ///
				Q8_2_x*_4  /*jobs*/ ///
				Q21_2_x*_4 /*blacks*/ ///
				Q24_2_x*_4 /*affirm action*/ ///
				Q26_2_x*_4 /*defense*/ ///
				Q28_2_x*_4 /*women*/ ///
				Q30_2_x*_4 /*abortion*/ ///
				Q32_2_x*_4 /*death penalty*/ ///
				Q34_2_x*_4 /*gay & lesbian*/ ///
				Q36_2_x*_4 /*environment*/ ///
				Q38_2_x*_4 /*spending*/ ///
				Q40_2_x*_4 /*internationalism*/), v(1)		
	label var method4 "Archival"
	
tab1 method*
	/*
	ANES = 26.83% (11)
	Other Survey = 68.29* (28)
	Experiment = 24.39% (10)
	Archival = 7.32% (3)
	*/
	
	
gen method5 = 0
	replace method5 = 1 if method1 == 1 | method2 == 1
	label var method5 "Any Survey"
	tab method5
		/*85.37 (35)*/
	
	
gen method6 = 0
	replace method6 = 1 if method1 == 1 & method3 == 1
	label var method6 "ANES+Experiment"
	tab method6
	/*4.88% (2)*/
	
gen method7 = 0
	replace method7 = 1 if method5 == 1 & method3 == 1
	label var method7 "Survey+Experiment"
	tab method7
	/*14.63% (6)*/
	
	
	
/*****************
Next, we'll reshape the data so that we can then produce
a siplified data-set with just the proportions for each type of
method use
******************/

/***Rehsaping****/

reshape long method, i(ResponseId) j(meth)

label def met 1 "ANES" 2 "Other Survey" 3 "Experiment" 4 "Archival" ///
	5 "Any Survey" 6 "ANES+Experiment" 7 "Survey+Experiment"
label values meth met




collapse (mean) method, by(meth)
list

gen id = _n
label var id "ID" 

graph bar method if id !=6, over(meth, ///
	relabel(2 `""Other" "Survey""' 5 `""Any" "Survey""' 6 `""Survey &" "Experiment""') ///
	label(labsize(vsmall))) ///
	blabel(bar, format(%9.2g)) scheme(s1mono) ///
	title(Data Source, size(medium)) ytitle("Proportion Used") ylabel(0(0.2)1)
	
	
graph save "method use 2009 to 2018", replace
graph export "method use 2009 to 2018.png", replace

rename method method09

save "Methods 2009 to 2018.dta", replace


	
	

	
	
	
	
	
/*****************************************************
			ANES Time Series Use
*****************************************************/
	
	
/********Calling and Cleaning the Data******/
clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
do "ANES Coding Project - New Data.do" 


/********Use******/

/****
the following anymatch code yields binary varialbes for
each of the three potential ANES answers. 
In other words, it produces a variable = 1 if 
*any* of the concepts was coded as using the ANES 1 [2, 3] 
times.
*****/ 

egen ts1 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(1)
label var ts1 "1 ANES Used"


egen ts2 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(2)
label var ts2 "2 ANES Used"

egen ts3 = anymatch(Q5_xx* /*concepts*/ ///
				Q9_xx* Q11_xx* Q13_xx* Q15_xx* ///
				Q17_xx* Q19_xx* Q21_xx* Q23_xx* ///
				Q25_xx* Q27_xx* Q29_xx*), v(3)
label var ts3 "3+ ANES Used"
				
tab1 ts*
	/*
	no surveys used 2 and only 2 ANES; either 1 or 3+
	*/
	
tab ts1 ts3

	/*
	11 articles total used the ANES
	2 of them used 
	
	Some surveys had concepts with different levels of 
	ANES use. But, at the survye level, 	
	7 used 3+ and 4 used only 1
		
		1 ANES |     3+ ANES Used
		  Used |         0          1 |     Total
	-----------+----------------------+----------
			 0 |        30          5 |        35 
			 1 |         4          2 |         6 
	-----------+----------------------+----------
		 Total |        34          7 |        41 

	*/
	


gen ts_use1 = .
	replace ts_use1 = 1 if ts1 == 1 & ts3 == 0 
	replace ts_use1 = 3 if ts3 == 1 & ts_use1 == . 
label def tsu 1 "1 ANES" 3 "3+ ANES", replace
label values ts_use1 tsu
	

collapse (mean) ts_use1 


, by(meth)

label var ts_use1 "TS Use for 11 Articles Using ANES"

catplot ts_use1, scheme(s1mono) vertical percent blabel(bar, format(%9.2g)) ///
	title(ANES Time Series Use, size(medium)) ylabel(0(20)100)

	/*manual edit of 'xtitle' to make it smaller*/
	
graph save "ts use" , replace



/*****************************************************
			Figure 7
*****************************************************/


clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"


graph combine "Comparison - Most Frequent" "Comparison - Centrality" "method use 2009 to 2018" "ts use", scheme(s1mono)

graph save "Figure 7", replace
graph export "Figure 7.png", replace
