/******************************************************************************
*******************************************************************************
*******************************************************************************
							Article Coding Project
							1980-2008 Data
							Concept Use Over Time
							Figures 3 and OA3-OA6
*******************************************************************************
*******************************************************************************
*******************************************************************************
******************************************************************************/


/****Calling and Cleaning the Data*****/
clear
cd "C:\Users\Joshua\Dropbox\Work\ANES Coding Project\Data and Do Files"
do "1980-2008 Initial Cleaning.do"

		
/*
To create the figures we want, we will reshape the data so that each row is
an article/concept pairing. We will then use the collapse function to 
create a new datset that that just focuses on the raw data that we want. 

To do this we will need to rename the concepts
and issues in a similar manner so that we can combine them. 
[If we wanted to treat them separately, we could skip this step.]
We will do this both for the appears/does not appear item and the
centra/not central item. 
*/

	/***Concepts****/
	
forval i = 1/48 {
	rename Q3_`i' topic`i'
	}
	
	
	/***Issues***/
/*topic*/
	/*jobs & sol*/
	rename Q7_1_1 topic49
	rename Q7_1_2 topic50
	rename Q7_1_3 topic51
	/*blacks*/
	rename Q7_2_1 topic52
	rename Q7_2_2 topic53
	rename Q7_2_3 topic54
	/*affirmative action*/
	rename Q7_3_1 topic55
	rename Q7_3_2 topic56
	rename Q7_3_3 topic57
	/*defense spending*/
	rename Q7_4_1 topic58
	rename Q7_4_2 topic59
	rename Q7_4_3 topic60
	/*women*/
	rename Q7_5_1 topic61
	rename Q7_5_2 topic62
	rename Q7_5_3 topic63
	/*abortion*/
	rename Q7_6_1 topic64
	 rename Q7_6_2 topic65
	 rename Q7_6_3 topic66
	/*death penalty*/
	 rename Q7_7_1 topic67
	 rename Q7_7_2 topic68
	 rename Q7_7_3 topic69
	/*gay*/
	 rename Q7_8_1 topic70
	 rename Q7_8_2 topic71
	 rename Q7_8_3 topic72
	/*environment*/
	rename Q7_9_1 topic73
	rename Q7_9_2 topic74
	rename Q7_9_3 topic75
	/*services*/
	rename Q7_10_1 topic76
	rename Q7_10_2 topic77
	rename Q7_10_3 topic78
	/*internationalism*/
	rename Q7_11_1 topic79
	rename Q7_11_2 topic80 
	rename Q7_11_3 topic81
	
	 

	/***Rehsaping****/

gen id = _n
	
reshape long topic, i(id) j(top)
order topic, after(top)

recode topic (.=0)
	/*this way we can use (mean) later to recover the proportions of articles
	with the code in each year*/

tab topic
	


	
	
/***Topic Codes**/
label def topic_code ///
 1 "Difference btw Parties" 2 "Feel About Parties" 3 "PID" ///
 4 "Party Perf.: Economy" 5 "Party Perf: Foreign Affairs" /// 
 6 "Feelings abt President" 7 "Feelings abt Pres Candidates" ///
 8 "Feelings abt Congressional Candidates" 9 "Emotions abt Pres" 10 "Emotions abt Pres Cand" ///
 11 "Likes/Dislikes abt Pres Candidates" 12 "President's Traits" 13 "Presidential Candidate's Traits" ///
 14 "Approval President Job Performance" 15 "Approval President Performance Economy" ///
 16 "Approval President Performance Foreign Policy" 17 "Approval Congress Job Performance" ///
 18 "Approval of Congressional Rep's Job Performance" ///
 19 "Economic Performance" 20 "Personal Economic Situation" 21 "Position of Country in World Affairs" ///
 22 "Political Interest" 23 "Political Knowledge" 24 "Campaign Activity" ///
 25 "Campaing Contact" 26 "Vote Choice" 27 "Turnout in Nat'l  Elections" 28 "Registration" ///
 29 "Lib/Con Values" 30 "Religious Values/Beliefs" ///
 31 "Religious Identity" 32 "Moral Traditionalism" ///
 33 "Equalitarianism" 34 "Trust in Gov't" 35 "Political Efficacy" ///
 36 "TV News Consumption" 37 "Internet News Consumption" 38 "Newspaper Consumption" ///
 39 "Radio News  Consumption" 40 "Feelings abt Social Groups" ///
 41 "Attitudes abt Blacks" 42 "Stereotypes" 43 "Racial Identity" 44 "Ethnic Identity" ///
 45 "Social Class" 46 "Personality" 47 "Problems facing Country" 48 "Att. abt Divided Gov't" ///
 49 "Jobs: Own Attitude" 50 "Jobs: Candidate" 51 "Jobs: Parties" 52 "Aid Blacks: Own Attitude" 53 "Aid Blacks: Candidate" 54 "Aid Blacks: Parties" ///
 55 "Affirmative Action:Own " 56 "Affirmative Action: Candidates" 57 "Affirmative Action: Parties" ///
 58 "Defense Spending: Own Attitude" 59 "Defense Spending: Candidates" 60 "Defense Spending: Parties" ///
 61 "Women Equality: Own Attitude" 62 "Women Equality: Candidates" 63 "Women Equality: Parties" ///
 64 "Abortion: Own Atttiude" 65  "Abortion: Candidates" 66 "Abortion: Parties" ///
 67 "Death Penalty: Own Attitude" 68 "Death Penalty: Candidates" 69 "Death Penalty: Parties" ///
 70 "Gay & Lesbian: Own Attitudes" 71 "Gay & Lesbian: Candidates" 72 "Gay & Lesbian: Parties" ///
 73 "Environment: Own Attitude" 74 "Environment: Candidates" 75 "Environment: Parties" ///
 76 "Spending: Own Attitude" 77 "Spending: Candidates" 78 "Spending: Parties" ///
 79 "Internationalism: Own Attitude" 80 "Internationalism: Candidates" 81 "Internationalism: Parties"
	
 
label values top topic_code
	

/*********Creating a datasheet with just the proportions by article and year*******/
	
collapse (mean) topic , by(top year)
list in 1/20	
list if top == 3

	
forvalues i = 1/81 {
	local t : label (top) `i'
	display "`t'"
	lowess topic year if top == `i', title("`t'", size(medium)) ///
			scheme(s1mono) note("")  ytitle("")
	graph save "concept use over time `i'" , replace	
	}
	


graph combine ///
	"concept use over time 26" /// 
	"concept use over time 3" /// 
	"concept use over time 27" /// 
	"concept use over time 29" /// 
	"concept use over time 43" /// 
	"concept use over time 23" /// 
	"concept use over time 76" /// 
	"concept use over time 49" /// 
	"concept use over time 19" /// 
	"concept use over time 22" /// 
	"concept use over time 52" /// 
	"concept use over time 20" /// 
	"concept use over time 14" /// 
	"concept use over time 40" /// 
	"concept use over time 24" , scheme(s1mono) rows(3)
	
	/*
	note: for the figure in text, i manually edited two 
	of the sub-graph titles to make them shorter
	*/
	
	graph save "Figure 3", replace
	graph export "Figure 3.png", replace

/*****Appendices Graphs****/

/*Figure OA3*/

graph combine ///
	"concept use over time 34" ///
	"concept use over time 64" ///
	"concept use over time 58" ///
	"concept use over time 79" ///
	"concept use over time 55" ///
	"concept use over time 61" ///
	"concept use over time 7" ///
	"concept use over time 35" ///
	"concept use over time 36" ///
	"concept use over time 31" ///
	"concept use over time 41" ///
	"concept use over time 38" ///
	"concept use over time 44" ///
	"concept use over time 2" ///
	"concept use over time 28" ///
	"concept use over time 25" , scheme(s1mono) rows(4)

	graph save "Figure OA3", replace
	graph export "Figure OA3.png", replace
	
graph combine ///	
	"concept use over time 73" ///
	"concept use over time 32" ///
	"concept use over time 1" ///
	"concept use over time 33" ///
	"concept use over time 42" ///
	"concept use over time 13" ///
	"concept use over time 30" ///
	"concept use over time 15" ///
	"concept use over time 47" ///
	"concept use over time 77" ///
	"concept use over time 59" ///
	"concept use over time 12" ///
	"concept use over time 11" ///
	"concept use over time 70" ///
	"concept use over time 53" ///
	"concept use over time 50" 	, rows(4) scheme(s1mono)

	graph save "Figure OA4", replace
	graph export "Figure OA4.png", replace
	
graph combine ///
	"concept use over time 62" ///
 	"concept use over time 8" ///
	"concept use over time 16" ///
	"concept use over time 45" ///
	"concept use over time 80" ///
	"concept use over time 6" ///
	"concept use over time 17" ///
	"concept use over time 65" ///
	"concept use over time 18" ///
	"concept use over time 51" ///
	"concept use over time 67" ///
	"concept use over time 39" ///
	"concept use over time 78" ///
	"concept use over time 66" ///
	"concept use over time 46" ///
	"concept use over time 54" , rows(4) scheme(s1mono)
	
graph save "Figure OA5", replace
graph export "Figure OA5.png", replace
	
	
graph combine ///
	"concept use over time 74" ///
	"concept use over time 56" ///
	"concept use over time 4" ///
	"concept use over time 63" ///
	"concept use over time 21" ///
	"concept use over time 57" ///
	"concept use over time 10" ///
	"concept use over time 37" ///
	"concept use over time 9" ///
	"concept use over time 60" ///
	"concept use over time 48" ///
	"concept use over time 75" ///
	"concept use over time 71" ///
	"concept use over time 5" ///
	"concept use over time 81" ///
	"concept use over time 68" ///
	"concept use over time 72" ///
	"concept use over time 69" , scheme(s1mono) rows(4)
	
	graph save "Figure OA6" , replace
	graph export "Figure OA6.png", replace

mm
